UniGraphic-Fork for ST7920-LCD-controller and SH1106. Tested with 128x64 LCD with SPI and 128x64-OLED with IIC

Dependents:   UniGraphic-St7920-Test AfficheurUTILECO

Fork of UniGraphic by GraphicsDisplay

Fork of the UniGraphic-Library for monochrome LCDs with ST7920 controller and 128x64-IIC-OLED-Display with SH1106-Controller

/media/uploads/charly/20170522_210344.jpg

/media/uploads/charly/20180425_230623.jpg

Had to adapt LCD for following reasons:

  • Give access to screenbuffer buffer[] to parent class
  • pixel() and pixel_read() as they are hardware-dependent
  • added reset-pin to IIC-Interface

GraphicDisplay:: sends buffer to LCD when auto_update is set to true.

Testprogram for ST7920 can be found here:

https://developer.mbed.org/users/charly/code/UniGraphic-St7920-Test/

Revision:
1:ff019d22b275
Parent:
0:75ec1b3cde17
Child:
4:12ba0ecc2c1f
--- a/Protocols/PAR8.h	Thu Feb 12 22:22:47 2015 +0000
+++ b/Protocols/PAR8.h	Fri Feb 13 15:25:10 2015 +0000
@@ -22,35 +22,65 @@
 
 protected:
   
-    /** Send command byte to display controller 
+    /** Send 8bit command to display controller 
     *
     * @param cmd: byte to send  
     *
     */   
-    virtual void wr_cmd(unsigned char cmd);
+    virtual void wr_cmd8(unsigned char cmd);
     
-    /** Send data byte to display controller 
+    /** Send 8bit data to display controller 
     *
     * @param data8: byte to send   
     *
     */   
-    virtual void wr_data8(unsigned char data8);
+    virtual void wr_data8(unsigned char data);
     
-    /** Send same data byte to display controller multiple times
+    /** Send same 8bit data to display controller multiple times
     *
     * @param data8: byte to send
     * @param count: how many
     *
     */   
-    virtual void wr_data8(unsigned char data8, unsigned int count);
+    virtual void wr_data8(unsigned char data, unsigned int count);
     
     /** Send array of data bytes to display controller
     *
-    * @param data8: unsigned char data array
+    * @param data: unsigned char data array
     * @param lenght: lenght of array
     *
     */   
-    virtual void wr_data8buf(unsigned char* data8, unsigned int lenght);
+    virtual void wr_data8buf(unsigned char* data, unsigned int lenght);
+    
+    /** Send 16bit command to display controller 
+    *
+    * @param cmd: halfword to send  
+    *
+    */   
+    virtual void wr_cmd16(unsigned short cmd);
+    
+    /** Send 16bit data to display controller 
+    *
+    * @param data: halfword to send   
+    *
+    */   
+    virtual void wr_data16(unsigned short data);
+    
+    /** Send same 16bit data to display controller multiple times
+    *
+    * @param data: halfword to send
+    * @param count: how many
+    *
+    */   
+    virtual void wr_data16(unsigned short data, unsigned int count);
+    
+    /** Send array of data shorts to display controller
+    *
+    * @param data: unsigned short data array
+    * @param lenght: lenght (in shorts)
+    *
+    */   
+    virtual void wr_data16buf(unsigned short* data, unsigned int lenght);
     
     /** HW reset sequence (without display init commands)   
     */
@@ -22,35 +22,65 @@
     *
-    * @param data8: byte to send   
+    * @param data: byte to send   
     *
     */   
@@ -22,35 +22,65 @@
     *
-    * @param data8: byte to send
+    * @param data: byte to send
     * @param count: how many
     *